@@ -34,7 +34,7 @@ def get_opcode_list(bytecode):
             else:
                 # is a push-like opcode
                 push_skip_times = push_mapping[code]
-                opcode = [loc, code, opcode_mapping.get(
+                opcode = [loc, code+bytecode[i+2:i+2+push_skip_times*2], opcode_mapping.get(
                     code, '<------- ERROR'), bytecode[i+2:i+2+push_skip_times*2]]
                 opcode_list.append(opcode)
         else:
@@ -126,8 +126,9 @@ def opcode_occurrence(opcode_list, collapse=0):
     - 2: Drop PUSH-like, DUP-like and SWAP-like opcodes, then replace all LOG-like opcodes with LOG.
     - 3: Drop all PUSH-like, DUP-like, SWAP-like and LOG-like opcodes.
     '''
-    
-    stat_opcode_list = collapse_opcode(opcode_list=opcode_list, collapse=collapse)
+
+    stat_opcode_list = collapse_opcode(
+        opcode_list=opcode_list, collapse=collapse)
 
     occurrence_stat = dict.fromkeys(stat_opcode_list, 0)
     opcode_list = collapse_opcode(opcode_list, collapse)
@@ -231,7 +232,7 @@ def split_bytecode(bytecode):
         args_start = bzzr_start + 64 + 4
 
     runtime_bytecode = bytecode[runtime_start:bzzr_start]
-    
+
     for i in range(args_start, len(bytecode), 64):
         aug = str('Arg [{}]: '.format(
             str((i-args_start) // 64))+bytecode[i:i+64])
@@ -248,9 +249,11 @@ def function_to_signature(function_name):
     output: string
     '''
     import sha3
-    signature = sha3.keccak_256(str(function_name).encode('utf-8')).hexdigest().lower()[:8]
+    signature = sha3.keccak_256(
+        str(function_name).encode('utf-8')).hexdigest().lower()[:8]
     return signature
 
+
 def signature_to_function(function_signature):
     '''
     Convert function signature to function definition by reverse query. See https://github.com/Yzstr/Function-Signatures.
@@ -265,13 +268,13 @@ def signature_to_function(function_signature):
     #     import subprocess
     #     subprocess.run(['git', 'clone', 'https://github.com/yzstr/Function-Signatures.git'])
 
-    
     import csv
-    with open('Function-Signature.csv','r') as f:
+    with open('Function-Signature.csv', 'r') as f:
         reader = csv.reader(f)
         res = [line[0] for line in reader if line[1] == function_signature]
     return res
 
+
 def get_function_definitions_list(function_signatures):
     '''
     Get function definitions by function siguature-to-definition convertion.
@@ -286,4 +289,15 @@ def get_function_definitions_list(function_signatures):
             definition_list.append(signature_to_function(signature))
     except:
         definition_list = ['Function Signature Database not Avaliable.']
-    return definition_list
\ No newline at end of file
+    return definition_list
+
+
+def fix_hex_string(hex_string):
+    '''
+    Fix truncated hex strings. '4e' -> '0x0000004e'
+
+    input: string 
+    output: string
+    '''
+    decimal_value = int(hex_string, 16)
+    return '0x'+str(hex(decimal_value))[2:].zfill(8)
